@@ -82,8 +82,8 @@ TEST_DATA = {
                 "Patient Name": "UCM, TG119",
                 "Patient ID": "0097",
                 "Plan Name": "1 Prostate-6FFF-TB2",
-                "Plan Date": "5/19/2020  4:17 PM",
-                "Meas Date": "5/20/2020  4:25 PM",
+                "Plan Date": "5/19/2020 4:17 PM",
+                "Meas Date": "5/20/2020 4:25 PM",
                 "Accepted Date": "",
                 "Energy": "6 MV, FFF",
                 "Daily Corr": "1.039",
@@ -96,7 +96,7 @@ TEST_DATA = {
                 "Gamma Pass Criteria": "95%",
                 "Gamma Dose Criteria": "2.0%",
                 "Gamma Dist Criteria": "2.0 mm",
-                "Beam Count": 2,
+                "Beam Count": "2",
             },
         },
         "6 MV": {
@@ -123,7 +123,7 @@ TEST_DATA = {
                 "Gamma Pass Criteria": "95%",
                 "Gamma Dose Criteria": "3.0%",
                 "Gamma Dist Criteria": "2.0 mm",
-                "Beam Count": 4,
+                "Beam Count": "4",
             },
         },
         "2ndPageTxSummary": {
@@ -136,8 +136,8 @@ TEST_DATA = {
                 "Patient Name": "UCM, TG119",
                 "Patient ID": "0097",
                 "Plan Name": "4 CShape50-D4",
-                "Plan Date": "11/20/2019  2:30 PM",
-                "Meas Date": "11/21/2019  6:46 PM",
+                "Plan Date": "11/20/2019 2:30 PM",
+                "Meas Date": "11/21/2019 6:46 PM",
                 "Accepted Date": "",
                 "Energy": "6 MV",
                 "Daily Corr": "1.000",
@@ -150,7 +150,7 @@ TEST_DATA = {
                 "Gamma Pass Criteria": "95%",
                 "Gamma Dose Criteria": "2.0%",
                 "Gamma Dist Criteria": "2.0 mm",
-                "Beam Count": 3,
+                "Beam Count": "3",
             },
         },
         "Dates with . and energy/daily_corr swap": {
@@ -162,24 +162,23 @@ TEST_DATA = {
             "data": {
                 "Patient Name": "",
                 "Patient ID": "",
-                "Plan Date": "09/05/2019  2:26 PM",
+                "Plan Date": "09/05/2019 2:26 PM",
                 "Plan Name": "1-2 RUL",
-                "Meas Date": "09/05/2019  7:05 PM",
-                "Accepted Date": "09/05/2019  7:15 PM",
+                "Meas Date": "09/05/2019 7:05 PM",
+                "Accepted Date": "09/05/2019 7:15 PM",
                 "Radiation Dev": "TrueBeam1",
                 "Energy": "6 MV, FFF",
                 "Daily Corr": "1.010",
                 "Norm Dose": "1151 cGy",
                 "Dev": "94.7%",
                 "DTA": "99.6%",
-                "DTA Criteria": "n.a.",
                 "Dose Dev": "-1.0%",
                 "Gamma-Index": "99.5%",
                 "Gamma Pass Criteria": "95%",
                 "Gamma Dose Criteria": "3.0%",
                 "Gamma Dist Criteria": "3.0 mm",
                 "Threshold": "10%",
-                "Beam Count": 3,
+                "Beam Count": "3",
             },
         },
         "Energy in beam name": {
@@ -191,24 +190,23 @@ TEST_DATA = {
             "data": {
                 "Patient Name": "",
                 "Patient ID": "",
-                "Plan Date": "1/19/2018  2:20 PM",
+                "Plan Date": "1/19/2018 2:20 PM",
                 "Plan Name": "D4 QA 1-1",
-                "Meas Date": "1/19/2018  4:42 PM",
-                "Accepted Date": "1/19/2018  4:44 PM",
+                "Meas Date": "1/19/2018 4:42 PM",
+                "Accepted Date": "1/19/2018 4:44 PM",
                 "Radiation Dev": "UC_M120",
                 "Energy": "6 MV",
                 "Daily Corr": "1.016",
                 "Norm Dose": "248 cGy",
                 "Dev": "99.1%",
                 "DTA": "99.0%",
-                "DTA Criteria": "n.a.",
                 "Dose Dev": "-0.3%",
                 "Gamma-Index": "99.3%",
                 "Gamma Pass Criteria": "95%",
                 "Gamma Dose Criteria": "3.0%",
                 "Gamma Dist Criteria": "3.0 mm",
                 "Threshold": "10%",
-                "Beam Count": 2,
+                "Beam Count": "2",
             },
         },
         "TxSummary block returns daily corr": {
@@ -220,24 +218,23 @@ TEST_DATA = {
             "data": {
                 "Patient Name": "",
                 "Patient ID": "",
-                "Plan Date": "6/13/2016  8:13 PM",
+                "Plan Date": "6/13/2016 8:13 PM",
                 "Plan Name": "1-2",
-                "Meas Date": "6/14/2016  5:57 PM",
-                "Accepted Date": "6/14/2016  6:33 PM",
+                "Meas Date": "6/14/2016 5:57 PM",
+                "Accepted Date": "6/14/2016 6:33 PM",
                 "Radiation Dev": "UCTB_92",
                 "Energy": "6 MV",
                 "Daily Corr": "1.016",
                 "Norm Dose": "235 cGy",
                 "Dev": "87.2%",
                 "DTA": "99.6%",
-                "DTA Criteria": "n.a.",
                 "Dose Dev": "-1.4%",
                 "Gamma-Index": "95.5%",
                 "Gamma Pass Criteria": "95%",
                 "Gamma Dose Criteria": "3.0%",
                 "Gamma Dist Criteria": "3.0 mm",
                 "Threshold": "10%",
-                "Beam Count": 2,
+                "Beam Count": "2",
             },
         },
         "Date index search": {
@@ -249,24 +246,23 @@ TEST_DATA = {
             "data": {
                 "Patient Name": "",
                 "Patient ID": "",
-                "Plan Date": "12/28/2015  4:59 PM",
+                "Plan Date": "12/28/2015 4:59 PM",
                 "Plan Name": "D4QA",
-                "Meas Date": "12/29/2015  6:50 PM",
-                "Accepted Date": "12/29/2015  6:52 PM",
+                "Meas Date": "12/29/2015 6:50 PM",
+                "Accepted Date": "12/29/2015 6:52 PM",
                 "Radiation Dev": "UCTB_92",
                 "Energy": "6 MV",
                 "Daily Corr": "1.033",
                 "Norm Dose": "958 cGy",
                 "Dev": "98.0%",
                 "DTA": "100.0%",
-                "DTA Criteria": "n.a.",
                 "Dose Dev": "-0.4%",
                 "Gamma-Index": "100.0%",
                 "Gamma Pass Criteria": "95%",
                 "Gamma Dose Criteria": "2.0%",
                 "Gamma Dist Criteria": "2.0 mm",
                 "Threshold": "10%",
-                "Beam Count": 1,
+                "Beam Count": "1",
             },
         },
         "No Composite/Fraction in Energy Block": {
@@ -278,23 +274,22 @@ TEST_DATA = {
             "data": {
                 "Patient Name": "",
                 "Patient ID": "",
-                "Plan Date": "8/28/2019  10:04 AM",
+                "Plan Date": "8/28/2019 10:04 AM",
                 "Plan Name": "1-2 HN 75Gy",
-                "Meas Date": "8/28/2019  5:48 PM",
+                "Meas Date": "8/28/2019 5:48 PM",
                 "Radiation Dev": "UC_M120",
                 "Energy": "6 MV",
                 "Daily Corr": "1.033",
                 "Norm Dose": "146 cGy",
                 "Dev": "91.0%",
                 "DTA": "97.0%",
-                "DTA Criteria": "n.a.",
                 "Dose Dev": "0.0%",
                 "Gamma-Index": "98.3%",
                 "Gamma Pass Criteria": "95%",
                 "Gamma Dose Criteria": "3.0%",
                 "Gamma Dist Criteria": "3.0 mm",
                 "Threshold": "10%",
-                "Beam Count": 2,
+                "Beam Count": "2",
             },
         },
         "AM/PM in date, month/day swapped": {
@@ -306,23 +301,50 @@ TEST_DATA = {
             "data": {
                 "Patient Name": "",
                 "Patient ID": "",
-                "Plan Date": "11/22/2017  11:01 AM",
+                "Plan Date": "11/22/2017 11:01 AM",
                 "Plan Name": "D4QA 1-1",
-                "Meas Date": "11/22/2017  3:57 PM",
+                "Meas Date": "11/22/2017 3:57 PM",
                 "Radiation Dev": "UC_M120",
                 "Energy": "6 MV",
                 "Daily Corr": "1.053",
                 "Norm Dose": "261 cGy",
                 "Dev": "99.6%",
                 "DTA": "99.6%",
-                "DTA Criteria": "n.a.",
                 "Dose Dev": "0.6%",
                 "Gamma-Index": "99.6%",
                 "Gamma Pass Criteria": "95%",
                 "Gamma Dose Criteria": "3.0%",
                 "Gamma Dist Criteria": "3.0 mm",
                 "Threshold": "10%",
-                "Beam Count": 2,
+                "Beam Count": "2",
+            },
+        },
+        "High resolution / Gy": {
+            "path": join(
+                DIRECTORIES["DELTA4_EXAMPLES"],
+                "UChicago",
+                "SCH_example_1.pdf",
+            ),
+            "data": {
+                "Patient Name": "",
+                "Patient ID": "",
+                "Plan Date": "12/29/2014 6:49 PM",
+                "Plan Name": "Dlt4QA_Prst",
+                "Meas Date": "12/29/2014 6:58 PM",
+                "Accepted Date": "",
+                "Radiation Dev": "SCHTrueBeam",
+                "Energy": "6 MV",
+                "Daily Corr": "1.005",
+                "Norm Dose": "2.47 Gy",
+                "Dev": "93.8%",
+                "DTA": "98.9%",
+                "Dose Dev": "-0.6%",
+                "Gamma-Index": "99.8%",
+                "Gamma Pass Criteria": "95%",
+                "Gamma Dose Criteria": "3.0%",
+                "Gamma Dist Criteria": "2.0 mm",
+                "Threshold": "20%",
+                "Beam Count": "4",
             },
         },
     },
